ACCOUNTS_URL = "https://accounts.pixiv.net"
APP_URL = "https://app-api.pixiv.net"
OAUTH_URL = "https://oauth.secure.pixiv.net"
SKETCH_URL = "https://sketch.pixiv.net"

OS = "android"
OS_VERSION = "7.0"
OS_MODEL = "SM-A310F"
VERSION = "5.0.96"

USER_AGENT = f"PixivAndroidApp/{VERSION} (Android {OS_VERSION}; {OS_MODEL})"

CLIENT_ID = "MOBrBDS8blbauoSck0ZfDbtuzpyT"
CLIENT_SECRET = "lsACyCD94FhDUtGTXi3QzcFE2uU1hqtDaKeqrdwj"
PROVISIONAL_TOKEN = "l-f9qZ0ZyqSwRyZs8-MymbtWBbSxmCu1pmbOlyisou8"
